@@ -18,7 +18,7 @@
  *
  */
 
-#ifndef QUALIFIER
+#ifndef READTAGS_DSL
 #include "general.h"  /* must always come first */
 
 #include "routines.h"
@@ -29,10 +29,10 @@
 #include <config.h>
 #endif
 
-#ifdef USE_STDBOOL_H
+#ifdef HAVE_STDBOOL_H
 #include <stdbool.h>
 #endif
-#endif
+#endif	/* READTAGS_DSL */
 
 #include "mio.h"
 
@@ -43,9 +43,8 @@
 #include <stdlib.h>
 #include <limits.h>
 
-#ifdef QUALIFIER
+#ifdef READTAGS_DSL
 #define xMalloc(n,Type)    (Type *)eMalloc((size_t)(n) * sizeof (Type))
-#define xCalloc(n,Type)    (Type *)eCalloc((size_t)(n), sizeof (Type))
 #define xRealloc(p,n,Type) (Type *)eRealloc((p), (n) * sizeof (Type))
 
 static void *eMalloc (const size_t size)
@@ -61,19 +60,6 @@ static void *eMalloc (const size_t size)
 	return buffer;
 }
 
-static void *eCalloc (const size_t count, const size_t size)
-{
-	void *buffer = calloc (count, size);
-
-	if (buffer == NULL)
-	{
-		fprintf(stderr, "out of memory");
-		abort ();
-	}
-
-	return buffer;
-}
-
 static void *eRealloc (void *const ptr, const size_t size)
 {
 	void *buffer;
@@ -95,10 +81,11 @@ static void eFree (void *const ptr)
 {
 	free (ptr);
 }
+#define eFreeNoNullCheck eFree
 
 #  define Assert(c) do {} while(0)
 #  define AssertNotReached() do {} while(0)
-#endif
+#endif	/* READTAGS_DSL */
 
 /* minimal reallocation chunk size */
 #define MIO_CHUNK_SIZE 4096
@@ -118,9 +105,9 @@ static void eFree (void *const ptr)
  * A #MIO object is created using mio_new_file(), mio_new_memory() or mio_new_mio(),
  * depending on whether you want file or in-memory operations.
  * Its life is managed by reference counting. Just after calling one of functions
- * for creating, the count is 1. mio_ref() increments the counter. mio_free()
+ * for creating, the count is 1. mio_ref() increments the counter. mio_unref()
  * decrements it. When the counter becomes 0, the #MIO object will be destroyed
- * in mio_free(). There is also some other convenient API to create file-based
+ * in mio_unref(). There is also some other convenient API to create file-based
  * #MIO objects for more complex cases, such as mio_new_file_full() and
  * mio_new_fp().
  *
@@ -189,10 +176,10 @@ struct _MIO {
  * as a close function. The former is useful e.g. if you need to wrap fopen()
  * for some reason (like filename encoding conversion for example), and the
  * latter allows you both to match your custom open function and to choose
- * whether the underlying #FILE object should or not be closed when mio_free()
+ * whether the underlying #FILE object should or not be closed when mio_unref()
  * is called on the returned object.
  *
- * Free-function: mio_free()
+ * Free-function: mio_unref()
  *
  * Returns: A new #MIO on success, or %NULL on failure.
  */
@@ -240,7 +227,7 @@ MIO *mio_new_file_full (const char *filename,
  * This function simply calls mio_new_file_full() with the libc's fopen() and
  * fclose() functions.
  *
- * Free-function: mio_free()
+ * Free-function: mio_unref()
  *
  * Returns: A new #MIO on success, or %NULL on failure.
  */
@@ -265,7 +252,7 @@ MIO *mio_new_file (const char *filename, const char *mode)
  * </programlisting>
  * </example>
  *
- * Free-function: mio_free()
+ * Free-function: mio_unref()
  *
  * Returns: A new #MIO on success or %NULL on failure.
  */
@@ -322,7 +309,7 @@ MIO *mio_new_fp (FILE *fp, MIOFCloseFunc close_func)
  * </programlisting>
  * </example>
  *
- * Free-function: mio_free()
+ * Free-function: mio_unref()
  *
  * Returns: A new #MIO on success, or %NULL on failure.
  */
@@ -370,7 +357,7 @@ MIO *mio_new_memory (unsigned char *data,
  *
  * The function doesn't move the file position of @base.
  *
- * Free-function: mio_free()
+ * Free-function: mio_unref()
  *
  */
 
@@ -404,7 +391,7 @@ MIO *mio_new_mio (MIO *base, long start, long size)
 	if (r != size)
 		goto cleanup;
 
-	submio = mio_new_memory (data, size, eRealloc, eFree);
+	submio = mio_new_memory (data, size, eRealloc, eFreeNoNullCheck);
 	if (! submio)
 		goto cleanup;
 
@@ -436,7 +423,7 @@ MIO *mio_ref        (MIO *mio)
  * Gets the underlying #FILE object associated with a #MIO file stream.
  *
  * <warning><para>The returned object may become invalid after a call to
- * mio_free() if the stream was configured to close the file when
+ * mio_unref() if the stream was configured to close the file when
  * destroyed.</para></warning>
  *
  * Returns: The underlying #FILE object of the given stream, or %NULL if the
@@ -461,7 +448,7 @@ FILE *mio_file_get_fp (MIO *mio)
  * Gets the underlying memory buffer associated with a #MIO memory stream.
  *
  * <warning><para>The returned pointer and size may become invalid after a
- * successful write on the stream or after a call to mio_free() if the stream
+ * successful write on the stream or after a call to mio_unref() if the stream
  * was configured to free the memory when destroyed.</para></warning>
  *
  * Returns: The memory buffer of the given #MIO stream, or %NULL if the stream
@@ -482,7 +469,7 @@ unsigned char *mio_memory_get_data (MIO *mio, size_t *size)
 }
 
 /**
- * mio_free:
+ * mio_unref:
  * @mio: A #MIO object
  *
  * Decrements the reference counter of a #MIO and destroys the #MIO
@@ -490,7 +477,7 @@ unsigned char *mio_memory_get_data (MIO *mio, size_t *size)
  *
  * Returns: Error code obtained from the registered MIOFCloseFunc or 0 on success.
  */
-int mio_free (MIO *mio)
+int mio_unref (MIO *mio)
 {
 	int rv = 0;
 
@@ -662,6 +649,11 @@ static int mem_try_resize (MIO *mio, size_t new_size)
 	return success;
 }
 
+int mio_try_resize (MIO *mio, size_t new_size)
+{
+	return mem_try_resize (mio, new_size);
+}
+
 /*
  * mem_try_ensure_space:
  * @mio: A #MIO object
@@ -822,7 +814,7 @@ int mio_vprintf (MIO *mio, const char *format, va_list ap)
 		old_size = mio->impl.mem.size;
 		va_copy (ap_copy, ap);
 		/* compute the size we will need into the buffer */
-		n = vsnprintf (&dummy, 1, format, ap_copy);
+		n = vsnprintf (&dummy, 1, format, ap_copy) + 1;
 		va_end (ap_copy);
 		if (mem_try_ensure_space (mio, n))
 		{
