@@ -758,20 +758,20 @@ static gboolean on_key_press(GtkWidget *widget, GdkEventKey *event, gpointer dat
 		return TRUE;
 	}
 
-	if (event->keyval == GDK_space)
+	if (event->keyval == GDK_KEY_space)
 	{
 		on_open_clicked(NULL, GINT_TO_POINTER(TRUE));
 		return TRUE;
 	}
 
-	if (( (event->keyval == GDK_Up || event->keyval == GDK_KP_Up) && (event->state & GDK_MOD1_MASK)) || /* FIXME: Alt-Up doesn't seem to work! */
-		(event->keyval == GDK_BackSpace) )
+	if (( (event->keyval == GDK_KEY_Up || event->keyval == GDK_KEY_KP_Up) && (event->state & GDK_MOD1_MASK)) || /* FIXME: Alt-Up doesn't seem to work! */
+		(event->keyval == GDK_KEY_BackSpace) )
 	{
 		on_go_up();
 		return TRUE;
 	}
 
-	if ((event->keyval == GDK_F10 && event->state & GDK_SHIFT_MASK) || event->keyval == GDK_Menu)
+	if ((event->keyval == GDK_KEY_F10 && event->state & GDK_SHIFT_MASK) || event->keyval == GDK_KEY_Menu)
 	{
 		GdkEventButton button_event;
 
@@ -942,7 +942,7 @@ static GtkWidget *make_filterbar(void)
 {
 	GtkWidget *label, *filterbar;
 
-	filterbar = gtk_hbox_new(FALSE, 1);
+	filterbar = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 1);
 
 	label = gtk_label_new(_("Filter:"));
 
@@ -1133,7 +1133,7 @@ void plugin_init(GeanyData *data)
 
 	filter = NULL;
 
-	file_view_vbox = gtk_vbox_new(FALSE, 0);
+	file_view_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	toolbar = make_toolbar();
 	gtk_box_pack_start(GTK_BOX(file_view_vbox), toolbar, FALSE, FALSE, 0);
 
@@ -1261,8 +1261,8 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	GtkWidget *label, *entry, *checkbox_of, *checkbox_hf, *checkbox_fp, *checkbox_pb, *vbox;
 	GtkWidget *box, *align;
 
-	vbox = gtk_vbox_new(FALSE, 6);
-	box = gtk_vbox_new(FALSE, 3);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+	box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 3);
 
 	label = gtk_label_new(_("External open command:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
@@ -1287,7 +1287,7 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	pref_widgets.show_hidden_checkbox = checkbox_hf;
 	g_signal_connect(checkbox_hf, "toggled", on_toggle_hidden, NULL);
 
-	box = gtk_vbox_new(FALSE, 3);
+	box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 3);
 	checkbox_of = gtk_check_button_new_with_label(_("Hide file extensions:"));
 	gtk_button_set_focus_on_click(GTK_BUTTON(checkbox_of), FALSE);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox_of), hide_object_files);
