@@ -390,7 +390,8 @@ class LexerHaskell : public DefaultLexer {
 
 public:
    LexerHaskell(bool literate_)
-      : literate(literate_)
+      : DefaultLexer(literate_ ? "literatehaskell" : "haskell", literate_ ? SCLEX_LITERATEHASKELL : SCLEX_HASKELL)
+	  , literate(literate_)
       , firstImportLine(-1)
       , firstImportIndent(0)
       {}
@@ -401,7 +402,7 @@ public:
    }
 
    int SCI_METHOD Version() const override {
-      return lvOriginal;
+      return lvIdentity;
    }
 
    const char * SCI_METHOD PropertyNames() override {
@@ -418,6 +419,10 @@ public:
 
    Sci_Position SCI_METHOD PropertySet(const char *key, const char *val) override;
 
+   const char * SCI_METHOD PropertyGet(const char *key) override {
+	   return osHaskell.PropertyGet(key);
+   }
+
    const char * SCI_METHOD DescribeWordListSets() override {
       return osHaskell.DescribeWordListSets();
    }
