@@ -57,7 +57,11 @@ class LinePPState {
 		return level >= 0 && level < 32;
 	}
 	int maskLevel() const {
-		return 1 << level;
+		if (level >= 0) {
+			return 1 << level;
+		} else {
+			return 1;
+		}
 	}
 public:
 	LinePPState() : state(0), ifTaken(0), level(-1) {
@@ -212,12 +216,13 @@ class LexerVerilog : public DefaultLexer {
 
 public:
 	LexerVerilog() :
+		DefaultLexer("verilog", SCLEX_VERILOG),
 		setWord(CharacterSet::setAlphaNum, "._", 0x80, true),
 		subStyles(styleSubable, 0x80, 0x40, activeFlag) {
 		}
 	virtual ~LexerVerilog() {}
 	int SCI_METHOD Version() const override {
-		return lvSubStyles;
+		return lvIdentity;
 	}
 	void SCI_METHOD Release() override {
 		delete this;
@@ -234,6 +239,9 @@ public:
 	Sci_Position SCI_METHOD PropertySet(const char* key, const char* val) override {
 	    return osVerilog.PropertySet(&options, key, val);
 	}
+	const char * SCI_METHOD PropertyGet(const char *key) override {
+		return osVerilog.PropertyGet(key);
+	}
 	const char* SCI_METHOD DescribeWordListSets() override {
 		return osVerilog.DescribeWordListSets();
 	}
