@@ -1,8 +1,7 @@
 /*
  *      dialogs.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2012 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2006-2012 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2005 The Geany contributors
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -41,8 +40,7 @@
 #include "ui_utils.h"
 #include "win32.h"
 
-#include "gtkcompat.h"
-
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 
@@ -306,7 +304,7 @@ static GtkWidget *add_file_open_extra_widget(GtkWidget *dialog)
 	GtkWidget *encoding_ebox, *encoding_label, *encoding_combo;
 
 	expander = gtk_expander_new_with_mnemonic(_("_More Options"));
-	vbox = gtk_vbox_new(FALSE, 6);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_add(GTK_CONTAINER(expander), vbox);
 
 	table = gtk_table_new(2, 4, FALSE);
@@ -492,6 +490,7 @@ static gboolean handle_save_as(const gchar *utf8_filename, gboolean rename_file)
 	GeanyDocument *doc = document_get_current();
 	gboolean success = FALSE;
 
+	g_return_val_if_fail(doc != NULL, FALSE);
 	g_return_val_if_fail(!EMPTY(utf8_filename), FALSE);
 
 	if (doc->file_name != NULL)
@@ -1291,7 +1290,7 @@ void dialogs_show_file_properties(GeanyDocument *doc)
 /* extra_text can be NULL; otherwise it is displayed below main_text.
  * if parent is NULL, main_widgets.window will be used
  * btn_1, btn_2, btn_3 can be NULL.
- * returns response_1, response_2 or response_3 */
+ * returns response_1, response_2, response_3, or GTK_RESPONSE_DELETE_EVENT if the dialog was discarded */
 static gint show_prompt(GtkWidget *parent,
 		const gchar *btn_1, GtkResponseType response_1,
 		const gchar *btn_2, GtkResponseType response_2,
@@ -1345,9 +1344,7 @@ static gint show_prompt(GtkWidget *parent,
 	if (btn_1 != NULL)
 		gtk_dialog_add_button(GTK_DIALOG(dialog), btn_1, response_1);
 
-	/* For a cancel button, use cancel response so user can press escape to cancel */
-	btn = gtk_dialog_add_button(GTK_DIALOG(dialog), btn_2,
-		utils_str_equal(btn_2, GTK_STOCK_CANCEL) ? GTK_RESPONSE_CANCEL : response_2);
+	btn = gtk_dialog_add_button(GTK_DIALOG(dialog), btn_2, response_2);
 	/* we don't want a default, but we need to override the apply button as default */
 	gtk_widget_grab_default(btn);
 	gtk_dialog_add_button(GTK_DIALOG(dialog), btn_3, response_3);
@@ -1355,8 +1352,6 @@ static gint show_prompt(GtkWidget *parent,
 	ret = gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
 
-	if (ret == GTK_RESPONSE_CANCEL)
-		ret = response_2;
 	return ret;
 }
 
