@@ -1,8 +1,7 @@
 /*
  *      geanyentryaction.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2008-2012 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2008-2012 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2008 The Geany contributors
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -23,11 +22,14 @@
  * This class is missing the action_create_menu_item() function and so can't be
  * used for creating menu items. */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
-#include "geany.h"
-#include "support.h"
-#include "ui_utils.h"
 #include "geanyentryaction.h"
+
+#include "ui_utils.h"
+
 #include <ctype.h>
 
 
