@@ -120,7 +120,6 @@ void msgwin_set_messages_dir(const gchar *messages_dir)
 
 static void load_color(const gchar *color_name, GdkColor *color)
 {
-#if GTK_CHECK_VERSION(3, 0, 0)
 	GdkRGBA rgba_color;
 	GtkWidgetPath *path = gtk_widget_path_new();
 	GtkStyleContext *ctx = gtk_style_context_new();
@@ -137,15 +136,6 @@ static void load_color(const gchar *color_name, GdkColor *color)
 
 	gtk_widget_path_unref(path);
 	g_object_unref(ctx);
-#else
-	gchar *path = g_strconcat("*.", color_name, NULL);
-
-	GtkSettings *settings = gtk_settings_get_default();
-	GtkStyle *style = gtk_rc_get_style_by_paths(settings, path, NULL, GTK_TYPE_WIDGET);
-	*color = style->fg[GTK_STATE_NORMAL];
-
-	g_free(path);
-#endif
 }
 
 
@@ -184,7 +174,7 @@ static gboolean on_msgwin_key_press_event(GtkWidget *widget, GdkEventKey *event,
 {
 	gboolean enter_or_return = ui_is_keyval_enter_or_return(event->keyval);
 
-	if (enter_or_return || event->keyval == GDK_space)
+	if (enter_or_return || event->keyval == GDK_KEY_space)
 	{
 		switch (GPOINTER_TO_INT(data))
 		{
@@ -374,10 +364,6 @@ void msgwin_compiler_add_string(gint msg_color, const gchar *msg)
 		gtk_tree_path_free(path);
 	}
 
-	/* calling build_menu_update for every build message would be overkill, TODO really should call it once when all done */
-	gtk_widget_set_sensitive(build_get_menu_items(-1)->menu_item[GBG_FIXED][GBF_NEXT_ERROR], TRUE);
-	gtk_widget_set_sensitive(build_get_menu_items(-1)->menu_item[GBG_FIXED][GBF_PREV_ERROR], TRUE);
-
 	if (utf8_msg != msg)
 		g_free(utf8_msg);
 }
@@ -498,7 +484,7 @@ void msgwin_status_add_string(const gchar *string)
 	gchar *statusmsg, *time_str;
 
 	/* add a timestamp to status messages */
-	time_str = utils_get_current_time_string();
+	time_str = utils_get_current_time_string(FALSE);
 	statusmsg = g_strconcat(time_str, ": ", string, NULL);
 	g_free(time_str);
 
