@@ -44,12 +44,11 @@
 #include "ui_utils.h"
 #include "utils.h"
 
-#include "gtkcompat.h"
-
 #include <unistd.h>
 #include <string.h>
 #include <ctype.h>
 
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 enum
@@ -332,7 +331,7 @@ static GtkWidget *add_find_checkboxes(GtkDialog *dialog)
 		"of the input and can be captured as normal characters by the pattern."));
 
 	/* Search features */
-	fbox = gtk_vbox_new(FALSE, 0);
+	fbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(fbox), check_regexp, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(fbox), check_multiline, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(fbox), checkbox7, FALSE, FALSE, 0);
@@ -362,12 +361,13 @@ static GtkWidget *add_find_checkboxes(GtkDialog *dialog)
 		G_CALLBACK(on_widget_toggled_set_insensitive), checkbox5);
 
 	/* Matching options */
-	mbox = gtk_vbox_new(FALSE, 0);
+	mbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(mbox), checkbox1, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(mbox), checkbox2, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(mbox), checkbox5, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new(TRUE, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
+	gtk_box_set_homogeneous(GTK_BOX(hbox), TRUE);
 	gtk_container_add(GTK_CONTAINER(hbox), fbox);
 	gtk_container_add(GTK_CONTAINER(hbox), mbox);
 	return hbox;
@@ -497,7 +497,7 @@ static void create_find_dialog(void)
 	g_signal_connect(find_dlg.dialog, "delete-event",
 			G_CALLBACK(gtk_widget_hide_on_delete), NULL);
 
-	sbox = gtk_hbox_new(FALSE, 6);
+	sbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(sbox), label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(sbox), entry, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), sbox, TRUE, FALSE, 0);
@@ -511,7 +511,7 @@ static void create_find_dialog(void)
 	g_signal_connect_after(exp, "activate",
 		G_CALLBACK(on_expander_activated), &find_dlg.all_expanded);
 
-	bbox = gtk_hbutton_box_new();
+	bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 
 	button = gtk_button_new_with_mnemonic(_("_Mark"));
 	gtk_widget_set_tooltip_text(button,
@@ -575,14 +575,16 @@ void search_show_find_dialog(void)
 	}
 	else
 	{
-		/* only set selection if the dialog is not already visible */
-		if (! gtk_widget_get_visible(find_dlg.dialog) && sel)
+		if (sel != NULL)
+		{
+			/* update the search text from current selection */
 			gtk_entry_set_text(GTK_ENTRY(find_dlg.entry), sel);
+			/* reset the entry widget's background colour */
+			ui_set_search_entry_background(find_dlg.entry, TRUE);
+		}
 		gtk_widget_grab_focus(find_dlg.entry);
 		set_dialog_position(find_dlg.dialog, find_dlg.position);
 		gtk_widget_show(find_dlg.dialog);
-		if (sel != NULL) /* when we have a selection, reset the entry widget's background colour */
-			ui_set_search_entry_background(find_dlg.entry, TRUE);
 		/* bring the dialog back in the foreground in case it is already open but the focus is away */
 		gtk_window_present(GTK_WINDOW(find_dlg.dialog));
 	}
@@ -600,7 +602,7 @@ static void send_replace_dialog_response(GtkButton *button, gpointer user_data)
 static gboolean
 on_widget_key_pressed_set_focus(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-	if (event->keyval == GDK_Tab)
+	if (event->keyval == GDK_KEY_Tab)
 	{
 		gtk_widget_grab_focus(GTK_WIDGET(user_data));
 		return TRUE;
@@ -669,11 +671,11 @@ static void create_replace_dialog(void)
 	g_signal_connect(replace_dlg.dialog, "delete-event",
 			G_CALLBACK(gtk_widget_hide_on_delete), NULL);
 
-	fbox = gtk_hbox_new(FALSE, 6);
+	fbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(fbox), label_find, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(fbox), replace_dlg.find_combobox, TRUE, TRUE, 0);
 
-	rbox = gtk_hbox_new(FALSE, 6);
+	rbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(rbox), label_replace, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(rbox), replace_dlg.replace_combobox, TRUE, TRUE, 0);
 
@@ -693,7 +695,7 @@ static void create_replace_dialog(void)
 	g_signal_connect_after(exp, "activate",
 		G_CALLBACK(on_expander_activated), &replace_dlg.all_expanded);
 
-	bbox = gtk_hbutton_box_new();
+	bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 
 	button = gtk_button_new_with_mnemonic(_("In Sessi_on"));
 	gtk_container_add(GTK_CONTAINER(bbox), button);
@@ -751,11 +753,13 @@ void search_show_replace_dialog(void)
 	}
 	else
 	{
-		/* only set selection if the dialog is not already visible */
-		if (! gtk_widget_get_visible(replace_dlg.dialog) && sel)
+		if (sel != NULL)
+		{
+			/* update the search text from current selection */
 			gtk_entry_set_text(GTK_ENTRY(replace_dlg.find_entry), sel);
-		if (sel != NULL) /* when we have a selection, reset the entry widget's background colour */
+			/* reset the entry widget's background colour */
 			ui_set_search_entry_background(replace_dlg.find_entry, TRUE);
+		}
 		gtk_widget_grab_focus(replace_dlg.find_entry);
 		set_dialog_position(replace_dlg.dialog, replace_dlg.position);
 		gtk_widget_show(replace_dlg.dialog);
@@ -886,7 +890,7 @@ static void create_fif_dialog(void)
 	gtk_entry_set_activates_default(GTK_ENTRY(entry), TRUE);
 	fif_dlg.search_combo = combo;
 
-	sbox = gtk_hbox_new(FALSE, 6);
+	sbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(sbox), label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(sbox), combo, TRUE, TRUE, 0);
 
@@ -914,7 +918,7 @@ static void create_fif_dialog(void)
 	/* update the entry when selection is changed */
 	g_signal_connect(combo_files_mode, "changed", G_CALLBACK(update_file_patterns), fcombo);
 
-	hbox = gtk_hbox_new(FALSE, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(hbox), label3, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), combo_files_mode, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), fcombo, TRUE, TRUE, 0);
@@ -945,7 +949,7 @@ static void create_fif_dialog(void)
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label2), e_combo);
 	fif_dlg.encoding_combo = e_combo;
 
-	ebox = gtk_hbox_new(FALSE, 6);
+	ebox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(ebox), label2, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(ebox), e_combo, TRUE, TRUE, 0);
 
@@ -983,17 +987,17 @@ static void create_fif_dialog(void)
 	gtk_widget_set_tooltip_text(checkbox2,
 			_("Invert the sense of matching, to select non-matching lines"));
 
-	lbox = gtk_vbox_new(FALSE, 0);
+	lbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add(GTK_CONTAINER(lbox), check_regexp);
 	gtk_container_add(GTK_CONTAINER(lbox), checkbox2);
 	gtk_container_add(GTK_CONTAINER(lbox), check_recursive);
 
-	rbox = gtk_vbox_new(FALSE, 0);
+	rbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add(GTK_CONTAINER(rbox), checkbox1);
 	gtk_container_add(GTK_CONTAINER(rbox), check_wholeword);
 	gtk_container_add(GTK_CONTAINER(rbox), gtk_label_new(NULL));
 
-	hbox = gtk_hbox_new(FALSE, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_container_add(GTK_CONTAINER(hbox), lbox);
 	gtk_container_add(GTK_CONTAINER(hbox), rbox);
 	gtk_container_add(GTK_CONTAINER(vbox), hbox);
@@ -1013,7 +1017,7 @@ static void create_fif_dialog(void)
 	g_signal_connect(check_extra, "toggled",
 		G_CALLBACK(on_widget_toggled_set_sensitive), entry_extra);
 
-	hbox = gtk_hbox_new(FALSE, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(hbox), check_extra, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), entry_extra, TRUE, TRUE, 0);
 	gtk_container_add(GTK_CONTAINER(vbox), hbox);
@@ -1059,10 +1063,8 @@ void search_show_find_in_files_dialog_full(const gchar *text, const gchar *dir)
 
 	if (!text)
 	{
-		/* only set selection if the dialog is not already visible, or has just been created */
-		if (doc && ! sel && ! gtk_widget_get_visible(fif_dlg.dialog))
+		if (doc && ! sel)
 			sel = editor_get_default_selection(doc->editor, search_prefs.use_current_word, NULL);
-
 		text = sel;
 	}
 	entry = gtk_bin_get_child(GTK_BIN(fif_dlg.search_combo));
