@@ -600,24 +600,14 @@ void sidebar_add_common_menu_items(GtkMenu *menu)
 
 	item = gtk_check_menu_item_new_with_mnemonic(_("Show S_ymbol List"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-#if GTK_CHECK_VERSION(3, 0, 0)
 	g_signal_connect(item, "draw", G_CALLBACK(on_sidebar_display_symbol_list_show), NULL);
-#else
-	g_signal_connect(item, "expose-event",
-			G_CALLBACK(on_sidebar_display_symbol_list_show), NULL);
-#endif
 	gtk_widget_show(item);
 	g_signal_connect(item, "activate",
 			G_CALLBACK(on_list_symbol_activate), NULL);
 
 	item = gtk_check_menu_item_new_with_mnemonic(_("Show _Document List"));
 	gtk_container_add(GTK_CONTAINER(menu), item);
-#if GTK_CHECK_VERSION(3, 0, 0)
 	g_signal_connect(item, "draw", G_CALLBACK(on_sidebar_display_open_files_show), NULL);
-#else
-	g_signal_connect(item, "expose-event",
-			G_CALLBACK(on_sidebar_display_open_files_show), NULL);
-#endif
 	gtk_widget_show(item);
 	g_signal_connect(item, "activate",
 			G_CALLBACK(on_list_document_activate), NULL);
@@ -889,7 +879,7 @@ static gboolean openfiles_go_to_selection(GtkTreeSelection *selection, guint key
 
 		/* switch to the doc and grab the focus */
 		document_show_tab(doc);
-		if (keyval != GDK_space)
+		if (keyval != GDK_KEY_space)
 			change_focus_to_editor(doc, tv.tree_openfiles);
 	}
 	return FALSE;
@@ -920,7 +910,7 @@ static gboolean taglist_go_to_selection(GtkTreeSelection *selection, guint keyva
 			{
 				navqueue_goto_line(doc, doc, line);
 				state = keybindings_get_modifiers(state);
-				if (keyval != GDK_space && ! (state & GEANY_PRIMARY_MOD_MASK))
+				if (keyval != GDK_KEY_space && ! (state & GEANY_PRIMARY_MOD_MASK))
 					change_focus_to_editor(doc, NULL);
 				else
 					handled = FALSE;
@@ -936,7 +926,7 @@ static gboolean sidebar_key_press_cb(GtkWidget *widget, GdkEventKey *event,
 											 gpointer user_data)
 {
 	may_steal_focus = FALSE;
-	if (ui_is_keyval_enter_or_return(event->keyval) || event->keyval == GDK_space)
+	if (ui_is_keyval_enter_or_return(event->keyval) || event->keyval == GDK_KEY_space)
 	{
 		GtkWidgetClass *widget_class = GTK_WIDGET_GET_CLASS(widget);
 		GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
