@@ -85,10 +85,7 @@
 
 /* GTK3 removed ComboBoxEntry, but we need a value to differentiate combo box with and
  * without entries, and it must not collide with other GTypes */
-#ifdef GTK_TYPE_COMBO_BOX_ENTRY
-#	define TYPE_COMBO_BOX_ENTRY GTK_TYPE_COMBO_BOX_ENTRY
-#else /* !GTK_TYPE_COMBO_BOX_ENTRY */
-#	define TYPE_COMBO_BOX_ENTRY get_combo_box_entry_type()
+#define TYPE_COMBO_BOX_ENTRY get_combo_box_entry_type()
 static GType get_combo_box_entry_type(void)
 {
 	static volatile gsize type = 0;
@@ -100,7 +97,6 @@ static GType get_combo_box_entry_type(void)
 	}
 	return type;
 }
-#endif /* !GTK_TYPE_COMBO_BOX_ENTRY */
 
 
 struct StashPref
