@@ -56,11 +56,10 @@
 
 #include "SciLexer.h"
 
-#include "gtkcompat.h"
-
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
+#include <gtk/gtk.h>
 
 
 typedef struct
@@ -620,6 +619,20 @@ static void add_top_level_items(GeanyDocument *doc)
 				NULL);
 			break;
 		}
+		case GEANY_FILETYPES_JULIA:
+		{
+			tag_list_add_groups(tag_store,
+				&(tv_iters.tag_variable), _("Constants"), ICON_VAR,
+				&(tv_iters.tag_namespace), _("Modules"), ICON_NAMESPACE,
+				&(tv_iters.tag_function), _("Functions"), ICON_METHOD,
+				&(tv_iters.tag_member), _("Fields"), ICON_MEMBER,
+				&(tv_iters.tag_macro), _("Macros"), ICON_MACRO,
+				&(tv_iters.tag_struct), _("Structures"), ICON_STRUCT,
+				&(tv_iters.tag_type), _("Types"), ICON_CLASS,
+				&(tv_iters.tag_externvar), _("Unknowns"), ICON_OTHER,
+				NULL);
+			break;
+		}
 		case GEANY_FILETYPES_HTML:
 		{
 			tag_list_add_groups(tag_store,
@@ -1905,11 +1918,7 @@ static void goto_popup_position_func(GtkMenu *menu, gint *x, gint *y, gboolean *
 
 	monitor_num = gdk_screen_get_monitor_at_point(screen, *x, *y);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 	gtk_widget_get_preferred_size(GTK_WIDGET(menu), NULL, &req);
-#else
-	gtk_widget_size_request(GTK_WIDGET(menu), &req);
-#endif
 
 #if GTK_CHECK_VERSION(3, 4, 0)
 	gdk_screen_get_monitor_workarea(screen, monitor_num, &monitor);
