@@ -1,8 +1,7 @@
 /*
  *      templates.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2012 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2006-2012 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2005 The Geany contributors
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -43,10 +42,9 @@
 #include "ui_utils.h"
 #include "utils.h"
 
-#include "gtkcompat.h"
-
 #include <time.h>
 #include <string.h>
+#include <gtk/gtk.h>
 
 
 GeanyTemplatePrefs template_prefs;
@@ -175,15 +173,13 @@ static gchar *get_template_from_file(const gchar *locale_fname, const gchar *doc
 									 GeanyFiletype *ft)
 {
 	gchar *content;
-	GString *template = NULL;
 
 	content = read_file(locale_fname);
 
 	if (content != NULL)
 	{
 		gchar *file_header;
-
-		template = g_string_new(content);
+		GString *template = g_string_new(content);
 
 		file_header = get_template_fileheader(ft);
 		templates_replace_valist(template,
@@ -285,7 +281,7 @@ static void create_file_template_menu(void)
 
 	new_with_template_toolbar_menu = gtk_menu_new();
 	g_object_ref(new_with_template_toolbar_menu);
-	geany_menu_button_action_set_menu(GEANY_MENU_BUTTON_ACTION(toolbar_get_action_by_name("New")), 
+	geany_menu_button_action_set_menu(GEANY_MENU_BUTTON_ACTION(toolbar_get_action_by_name("New")),
 		new_with_template_toolbar_menu);
 }
 
@@ -617,8 +613,9 @@ static gchar *run_command(const gchar *command, const gchar *file_name,
 	}
 	else
 	{
-		g_warning(_("Cannot execute command \"%s\" from the template: %s. "
-			"Check the path in the template."), command, error->message);
+		g_warning(_("Cannot execute template command \"%s\". "
+			"Hint: incorrect paths in the command are a common cause of errors. "
+			"Error: %s."), command, error->message);
 		g_error_free(error);
 	}
 
@@ -630,16 +627,16 @@ static gchar *run_command(const gchar *command, const gchar *file_name,
 static void templates_replace_command(GString *text, const gchar *file_name,
 							   const gchar *file_type, const gchar *func_name)
 {
-	gchar *match = NULL;
-	gchar *wildcard = NULL;
-	gchar *cmd;
-	gchar *result;
+	gchar *match;
 
 	g_return_if_fail(text != NULL);
 
 	while ((match = strstr(text->str, "{command:")) != NULL)
 	{
-		cmd = match;
+		gchar *wildcard;
+		gchar *cmd = match;
+		gchar *result;
+
 		while (*match != '}' && *match != '\0')
 			match++;
 
