@@ -398,9 +398,7 @@ GtkWidget *toolbar_init(void)
 	gtk_ui_manager_insert_action_group(uim, group, 0);
 
 	toolbar = toolbar_reload(NULL);
-#if GTK_CHECK_VERSION(3, 0, 0)
 	gtk_style_context_add_class(gtk_widget_get_style_context(toolbar), "primary-toolbar");
-#endif
 
 	gtk_settings = gtk_widget_get_settings(GTK_WIDGET(toolbar));
 	if (gtk_settings != NULL)
@@ -1031,14 +1029,14 @@ static TBEditorWidget *tb_editor_create_dialog(GtkWindow *parent)
 	g_signal_connect(button_add, "clicked", G_CALLBACK(tb_editor_btn_add_clicked_cb), tbw);
 	g_signal_connect(button_remove, "clicked", G_CALLBACK(tb_editor_btn_remove_clicked_cb), tbw);
 
-	vbox_buttons = gtk_vbox_new(FALSE, 6);
+	vbox_buttons = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
 	/* FIXME this is a little hack'ish, any better ideas? */
 	gtk_box_pack_start(GTK_BOX(vbox_buttons), gtk_label_new(""), TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox_buttons), button_add, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox_buttons), button_remove, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox_buttons), gtk_label_new(""), TRUE, TRUE, 0);
 
-	hbox = gtk_hbox_new(FALSE, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(hbox), swin_available, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox_buttons, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), swin_used, TRUE, TRUE, 0);
