@@ -38,12 +38,11 @@
 #include "utils.h"
 #include "win32.h"
 
-#include "gtkcompat.h"
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
+#include <gtk/gtk.h>
 
 
 enum
@@ -427,7 +426,7 @@ static void cc_show_dialog_custom_commands(void)
 		}
 	}
 
-	buttonbox = gtk_hbutton_box_new();
+	buttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_set_spacing(GTK_BOX(buttonbox), 6);
 	gtk_box_pack_start(GTK_BOX(vbox), buttonbox, FALSE, FALSE, 0);
 	cc.button_add = gtk_button_new_from_stock(GTK_STOCK_ADD);
