@@ -1,8 +1,7 @@
 /*
  *      win32.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2012 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2006-2012 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2005 The Geany contributors
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -19,9 +18,17 @@
  *      51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifndef GEANY_WIN32_H
+#define GEANY_WIN32_H 1
+
+#include "document.h"
+
+#include "gtkcompat.h"
+
 
 #ifdef G_OS_WIN32
 
+G_BEGIN_DECLS
 
 void win32_show_pref_file_dialog(GtkEntry *item);
 
@@ -52,15 +59,16 @@ void win32_init_debug_code(void);
 
 void win32_set_working_directory(const gchar *dir);
 
-gboolean win32_get_exit_status(GPid child_pid);
-
-gboolean win32_spawn(const gchar *dir, gchar **argv, gchar **env, GSpawnFlags flags,
-					 gchar **std_out, gchar **std_err, gint *exit_status, GError **error);
-
 gchar *win32_get_shortcut_target(const gchar *file_name);
 
 gchar *win32_get_installation_dir(void);
 
 gchar *win32_expand_environment_variables(const gchar *str);
 
-#endif
+gchar *win32_get_user_config_dir(void);
+
+G_END_DECLS
+
+#endif /* G_OS_WIN32 */
+
+#endif /* GEANY_WIN32_H */
